pub struct OraclePriceUpdate {
pub price: i64,
pub exponent: i32,
}Fields
price: i64exponent: i32Trait Implementations
Sourceimpl BorshDeserialize for OraclePriceUpdate
impl BorshDeserialize for OraclePriceUpdate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OraclePriceUpdate
impl BorshSerialize for OraclePriceUpdate
Sourceimpl Clone for OraclePriceUpdate
impl Clone for OraclePriceUpdate
Sourcefn clone(&self) -> OraclePriceUpdate
fn clone(&self) -> OraclePriceUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OraclePriceUpdate
impl Debug for OraclePriceUpdate
Sourceimpl PartialEq for OraclePriceUpdate
impl PartialEq for OraclePriceUpdate
impl Eq for OraclePriceUpdate
impl StructuralPartialEq for OraclePriceUpdate